{% extends "base.html" %}
{% block content %}
<section class="section">
  <div class="container" style="max-width:720px;">
    <h1 class="title">Delete the file "{{file}}"?</h1>
    <p class="notification is-warning is-light">The file will be deleted from the disk.</p>
    <form method="post">
      <button type="submit" class="button">Delete</button>
    </form>
  </div>
</section>
{% endblock %}
